@@ -1,10 +1,11 @@
-# $Id: dagflat.pm,v 1.21 2004/10/04 20:23:15 allenday Exp $
 #
 # BioPerl module for Bio::OntologyIO::dagflat
 #
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+#
 # Cared for by Hilmar Lapp, hlapp at gmx.net
 #
-# (c) Christian M. Zmasek, czmasek@gnf.org, 2002.
+# (c) Christian M. Zmasek, czmasek-at-burnham.org, 2002.
 # (c) Hilmar Lapp, hlapp at gmx.net, 2003.
 # (c) GNF, Genomics Institute of the Novartis Research Foundation, 2002.
 #
@@ -23,7 +24,7 @@
 
 =head1 NAME
 
-dagflat - a base class parser for GO flat-file type formats 
+Bio::OntologyIO::dagflat - a base class parser for GO flat-file type formats
 
 =head1 SYNOPSIS
 
@@ -32,11 +33,11 @@ dagflat - a base class parser for GO flat-file type formats
   # do not use directly -- use via Bio::OntologyIO
   # e.g., the GO parser is a simple extension of this class
   my $parser = Bio::OntologyIO->new
-	( -format       => "go",
-          -defs_file    => "/home/czmasek/GO/GO.defs",
-	  -files        => ["/home/czmasek/GO/component.ontology",
-	                    "/home/czmasek/GO/function.ontology",
-	                    "/home/czmasek/GO/process.ontology"] );
+        ( -format       => "go",
+     -defs_file    => "/home/czmasek/GO/GO.defs",
+          -files        => ["/home/czmasek/GO/component.ontology",
+                            "/home/czmasek/GO/function.ontology",
+                            "/home/czmasek/GO/process.ontology"] );
 
   my $go_ontology = $parser->next_ontology();
 
@@ -53,30 +54,40 @@ Needs Graph.pm from CPAN.
 =head2 Mailing Lists
 
 User feedback is an integral part of the evolution of this and other
-Bioperl modules. Send your comments and suggestions preferably to the 
+Bioperl modules. Send your comments and suggestions preferably to the
 Bioperl mailing lists  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org                         - General discussion
-  http://bio.perl.org/MailList.html             - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
 
 =head2 Reporting Bugs
 
-report bugs to the Bioperl bug tracking system to help us keep track
- the bugs and their resolution.  Bug reports can be submitted via
- email or the web:
+Report bugs to the Bioperl bug tracking system to help us keep track
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bio.perl.org
-  http://bugzilla.bioperl.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR
 
 Christian M. Zmasek
 
-Email: czmasek@gnf.org  or  cmzmasek@yahoo.com
+Email: czmasek-at-burnham.org  or  cmzmasek@yahoo.com
 
-WWW:   http://www.genetics.wustl.edu/eddy/people/zmasek/
+WWW:   http://monochrome-effect.net/
 
-Address: 
+Address:
 
   Genomics Institute of the Novartis Research Foundation
   10675 John Jay Hopkins Drive
@@ -98,22 +109,21 @@ methods. Internal methods are usually preceded with a _
 
 
 package  Bio::OntologyIO::dagflat;
-
-use vars qw( @ISA );
+$Bio::OntologyIO::dagflat::VERSION = '1.7.7';
 use strict;
 
 use Bio::Root::IO;
-use Bio::Ontology::SimpleGOEngine;
+use Bio::Ontology::OBOEngine;
 use Bio::Ontology::Ontology;
 use Bio::Ontology::OntologyStore;
 use Bio::Ontology::TermFactory;
-use Bio::OntologyIO;
+use Bio::Annotation::DBLink;
 
 use constant TRUE         => 1;
 use constant FALSE        => 0;
 
 
-@ISA = qw( Bio::OntologyIO );
+use base qw(Bio::OntologyIO);
 
 
 =head2 new
@@ -126,7 +136,7 @@ use constant FALSE        => 0;
                                         "/path/to/function.ontology",
                                         "/path/to/process.ontology"] );
  Function: Creates a new dagflat parser.
- Returns : A new dagflat parser object, implementing L<Bio::OntologyIO>.
+ Returns : A new dagflat parser object, implementing Bio::OntologyIO.
  Args    : -defs_file  => the name of the file holding the term
                           definitions
            -files      => a single ontology flat file holding the
@@ -138,7 +148,7 @@ use constant FALSE        => 0;
                           also be specified via the -file parameter
            -ontology_name => the name of the ontology; if not specified the
                           parser will auto-discover it by using the term
-                          that starts with a '$', and converting underscores
+                          that starts with a $, and converting underscores
                           to spaces
            -engine     => the Bio::Ontology::OntologyEngineI object
                           to be reused (will be created otherwise); note
@@ -146,6 +156,8 @@ use constant FALSE        => 0;
                           qualify as well since that one inherits from the
                           former.
 
+See L<Bio::OntologyIO>.
+
 =cut
 
 # in reality, we let OntologyIO::new do the instantiation, and override
@@ -154,7 +166,7 @@ sub _initialize {
   my ($self, %arg) = @_;
 
   my ( $defs_file_name,$files,$defs_url,$url,$name,$eng ) =
-	$self->_rearrange([qw( DEFS_FILE
+        $self->_rearrange([qw( DEFS_FILE
                            FILES
                            DEFS_URL
                            URL
@@ -173,7 +185,7 @@ sub _initialize {
   delete $self->{'_ontologies'};
 
   # ontology engine (and possibly name if it's an OntologyI)
-  $eng = Bio::Ontology::SimpleGOEngine->new() unless $eng;
+  $eng = Bio::Ontology::OBOEngine->new() unless $eng;
   if($eng->isa("Bio::Ontology::OntologyI")) {
     $self->ontology_name($eng->name());
     $eng = $eng->engine() if $eng->can('engine');
@@ -204,8 +216,8 @@ sub _initialize {
 
  Title   : ontology_name
  Usage   : $obj->ontology_name($newval)
- Function: Get/set the name of the ontology parsed by this module. 
- Example : 
+ Function: Get/set the name of the ontology parsed by this module.
+ Example :
  Returns : value of ontology_name (a scalar)
  Args    : on set, new value (a scalar or undef, optional)
 
@@ -223,7 +235,7 @@ sub ontology_name{
 =head2 parse
 
  Title   : parse()
- Usage   : $parser->parse();   
+ Usage   : $parser->parse();
  Function: Parses the files set with "new" or with methods
            defs_file and _flat_files.
 
@@ -242,12 +254,12 @@ sub parse {
     #warn "PARSING";
     # setup the default term factory if not done by anyone yet
     $self->term_factory(Bio::Ontology::TermFactory->new(
-					     -type => "Bio::Ontology::Term"))
-	unless $self->term_factory();
+                                             -type => "Bio::Ontology::Term"))
+        unless $self->term_factory();
 
     # create the ontology object itself
     my $ont = Bio::Ontology::Ontology->new(-name => $self->ontology_name(),
-					   -engine => $self->_ont_engine());
+                                           -engine => $self->_ont_engine());
 
     # parse definitions
     while( my $term = $self->_next_term() ) {
@@ -287,7 +299,7 @@ sub parse {
         $self->close();
         $self->_initialize_io(-file => shift(@{$self->_flat_files()}));
       } else {
-	    last; # nothing else to parse so terminate the loop
+            last; # nothing else to parse so terminate the loop
       }
     }
     $self->_add_ontology($ont);
@@ -324,7 +336,7 @@ sub next_ontology {
       return $ont;
     }
   }
-  return undef;
+  return;
 }
 
 =head2 defs_file
@@ -341,10 +353,10 @@ sub defs_file {
   my $self = shift;
 
   if ( @_ ) {
-	my $f = shift;
+        my $f = shift;
     $self->{ "_defs_file_name" } = $f;
-	$self->_defs_io->close() if $self->_defs_io();
-	if(defined($f)) {
+        $self->_defs_io->close() if $self->_defs_io();
+        if(defined($f)) {
       $self->_defs_io( Bio::Root::IO->new( -input => $f ) );
     }
   }
@@ -357,7 +369,7 @@ sub defs_url {
   if(defined($val)){
     $self->{'_defs_url'} = $val;
 
-	$self->_defs_io->close() if $self->_defs_io();
+        $self->_defs_io->close() if $self->_defs_io();
     $self->_defs_io( Bio::Root::IO->new( -url => $val ) );
   }
   return $self->{'_defs_url'};
@@ -433,11 +445,10 @@ sub _flat_files {
  Usage   : $obj->_defs_io($newval)
  Function: Get/set the Bio::Root::IO instance representing the
            definition file, if provided (see defs_file()).
- Example : 
+ Example :
  Returns : value of _defs_io (a Bio::Root::IO object)
  Args    : on set, new value (a Bio::Root::IO object or undef, optional)
 
-
 =cut
 
 sub _defs_io{
@@ -451,12 +462,12 @@ sub _add_ontology {
     my $self = shift;
     $self->{'_ontologies'} = [] unless exists($self->{'_ontologies'});
     foreach my $ont (@_) {
-	$self->throw(ref($ont)." does not implement Bio::Ontology::OntologyI")
-	    unless ref($ont) && $ont->isa("Bio::Ontology::OntologyI");
-	# the ontology name may have been auto-discovered while parsing
-	# the file
-	$ont->name($self->ontology_name) unless $ont->name();
-	push(@{$self->{'_ontologies'}}, $ont);
+        $self->throw(ref($ont)." does not implement Bio::Ontology::OntologyI")
+            unless ref($ont) && $ont->isa("Bio::Ontology::OntologyI");
+        # the ontology name may have been auto-discovered while parsing
+        # the file
+        $ont->name($self->ontology_name) unless $ont->name();
+        push(@{$self->{'_ontologies'}}, $ont);
     }
 }
 
@@ -465,7 +476,7 @@ sub _add_term {
     my ( $self, $term, $ont ) = @_;
     $term->ontology($ont) if $ont && (! $term->ontology);
     $self->_ont_engine()->add_term( $term );
-} # _add_term 
+} # _add_term
 
 
 
@@ -474,7 +485,7 @@ sub _part_of_relationship {
     my $self = shift;
 
     return $self->_ont_engine()->part_of_relationship(@_);
-} # _part_of_relationship 
+} # _part_of_relationship
 
 
 
@@ -483,14 +494,14 @@ sub _is_a_relationship {
     my $self = shift;
 
     return $self->_ont_engine()->is_a_relationship(@_);
-} # _is_a_relationship 
+} # _is_a_relationship
 
 # This simply delegates. See SimpleGOEngine
 sub _related_to_relationship {
     my $self = shift;
 
     return $self->_ont_engine()->related_to_relationship(@_);
-} # _is_a_relationship 
+} # _is_a_relationship
 
 
 
@@ -519,28 +530,33 @@ sub _has_term {
 sub _parse_flat_file {
   my $self = shift;
   my $ont  = shift;
-    
+
   my @stack       = ();
   my $prev_spaces = -1;
   my $prev_term   = "";
-    
+
   while ( my $line = $self->_readline() ) {
-        
-	if ( $line =~ /^!/ ) {
-	  next;
-	}
+
+        if ( $line =~ /^!/ ) {
+          next;
+        }
 
         # split into term specifications
         my @termspecs = split(/ (?=[%<])/, $line);
         # the first element is whitespace only
         shift(@termspecs) if $termspecs[0] =~ /^\s*$/;
-        
-        # parse out the focus term
-	my $current_term   = $self->_get_first_termid( $termspecs[0] );
-	my @syns           = $self->_get_synonyms( $termspecs[0] );
-	my @sec_go_ids     = $self->_get_secondary_termids( $termspecs[0] );
-	my @cross_refs     = $self->_get_db_cross_refs( $termspecs[0] );
 
+        # parse out the focus term
+        my $current_term   = $self->_get_first_termid( $termspecs[0] );
+        my @syns           = $self->_get_synonyms( $termspecs[0] );
+        my @sec_go_ids     = $self->_get_secondary_termids( $termspecs[0] );
+        my @cross          = $self->_get_db_cross_refs( $termspecs[0] );
+        my @cross_refs;
+        foreach my $cross_ref (@cross) {
+            $cross_ref eq $current_term && next;
+            push(@cross_refs, $cross_ref);
+        }
+        
         # parse out the parents of the focus term
         shift(@termspecs);
         my @isa_parents = ();
@@ -554,107 +570,107 @@ sub _parse_flat_file {
                 $self->warn("unhandled relationship type in '".$parent."'");
             }
         }
-        
-	if ( ! $self->_has_term( $current_term ) ) {
-	  my $term =$self->_create_ont_entry($self->_get_name($line,
+
+        if ( ! $self->_has_term( $current_term ) ) {
+          my $term =$self->_create_ont_entry($self->_get_name($line,
                                                               $current_term),
                                              $current_term );
-	  $self->_add_term( $term, $ont );
-	}
-        
-	my $current_term_object = $self->_ont_engine()->get_terms( $current_term );
-        
-	$current_term_object->add_dblink( @cross_refs );
-	$current_term_object->add_secondary_id( @sec_go_ids );
-	$current_term_object->add_synonym( @syns );
-	unless ( $line =~ /^\$/ ) {
-	  $current_term_object->ontology( $ont );
-	}
-	foreach my $parent ( @isa_parents ) {
-	  if ( ! $self->_has_term( $parent ) ) {
-		my $term = $self->_create_ont_entry($self->_get_name($line,
+          $self->_add_term( $term, $ont );
+        }
+
+        my $current_term_object = $self->_ont_engine()->get_terms( $current_term );
+        my $anno = $self->_to_annotation(\@cross_refs);
+        $current_term_object->add_dbxref(-dbxrefs => $anno);
+        $current_term_object->add_secondary_id( @sec_go_ids );
+        $current_term_object->add_synonym( @syns );
+        unless ( $line =~ /^\$/ ) {
+          $current_term_object->ontology( $ont );
+        }
+        foreach my $parent ( @isa_parents ) {
+          if ( ! $self->_has_term( $parent ) ) {
+                my $term = $self->_create_ont_entry($self->_get_name($line,
                                                                      $parent),
                                                     $parent );
-		$self->_add_term( $term, $ont );
-	  }
-            
-	  $self->_add_relationship( $parent,
+                $self->_add_term( $term, $ont );
+          }
+
+          $self->_add_relationship( $parent,
                                     $current_term,
                                     $self->_is_a_relationship(),
                                     $ont);
-          
-	}
-	foreach my $parent ( @partof_parents ) {
-	  if ( ! $self->_has_term( $parent ) ) {
-		my $term = $self->_create_ont_entry($self->_get_name($line,
+
+        }
+        foreach my $parent ( @partof_parents ) {
+          if ( ! $self->_has_term( $parent ) ) {
+                my $term = $self->_create_ont_entry($self->_get_name($line,
                                                                      $parent),
                                                     $parent );
-		$self->_add_term( $term, $ont );
-	  }
-           
-	  $self->_add_relationship( $parent,
+                $self->_add_term( $term, $ont );
+          }
+
+          $self->_add_relationship( $parent,
                                     $current_term,
                                     $self->_part_of_relationship(),
                                     $ont);
-	}
-        
-	my $current_spaces = $self->_count_spaces( $line );
-        
-	if ( $current_spaces != $prev_spaces  ) {
-       
-	  if ( $current_spaces == $prev_spaces + 1 ) {
-		push( @stack, $prev_term ); 
-	  } elsif ( $current_spaces < $prev_spaces ) {
-		my $n = $prev_spaces -  $current_spaces;
-		for ( my $i = 0; $i < $n; ++$i ) {
-		  pop( @stack );
-		}
-	  } else {
-		$self->throw( "format error (file ".$self->file.")" );
-	  } 
-	}
+        }
 
-	my $parent = $stack[ @stack - 1 ];
+        my $current_spaces = $self->_count_spaces( $line );
 
-	# add a relationship if the line isn\'t the one with the root term
-	# of the ontology (which is also the name of the ontology)
-	if ( index($line,'$') != 0 ) {
-	  #adding @reltype@ syntax
-	  if ( $line !~ /^\s*([<%~]|\@\w+?\@)/ ) {
-		$self->throw( "format error (file ".$self->file.") offending line:\n$line" );
-	  }
+        if ( $current_spaces != $prev_spaces  ) {
 
-	  my($relstring) = $line =~ /^\s*([<%~]|\@[^\@]+?\@)/;
+          if ( $current_spaces == $prev_spaces + 1 ) {
+                push( @stack, $prev_term );
+          } elsif ( $current_spaces < $prev_spaces ) {
+                my $n = $prev_spaces -  $current_spaces;
+                for ( my $i = 0; $i < $n; ++$i ) {
+                  pop( @stack );
+                }
+          } else {
+                $self->throw( "format error (file ".$self->file.")" );
+          }
+        }
 
-	  my $reltype;
+        my $parent = $stack[ @stack - 1 ];
 
-	  if ($relstring eq '<') {
-		$reltype = $self->_part_of_relationship;
-	  } elsif ($relstring eq '%') {
-		$reltype = $self->_is_a_relationship;
-	  } elsif ($relstring eq '~') {
-		$reltype = $self->_related_to_relationship;
-	  } else {
-		$relstring =~ s/\@//g;
-		if ($self->_ont_engine->get_relationship_type($relstring)) {
-		  $reltype = $self->_ont_engine->get_relationship_type($relstring);
-		} else {
-		  $self->_ont_engine->add_relationship_type($relstring, $ont);
-		  $reltype = $self->_ont_engine->get_relationship_type($relstring);
-		}
-	  }
+        # add a relationship if the line isn\'t the one with the root term
+        # of the ontology (which is also the name of the ontology)
+        if ( index($line,'$') != 0 ) {
+          #adding @reltype@ syntax
+          if ( $line !~ /^\s*([<%~]|\@\w+?\@)/ ) {
+                $self->throw( "format error (file ".$self->file.") offending line:\n$line" );
+          }
 
-	  #my $reltype = ($line =~ /^\s*</) ?
-	  #$self->_part_of_relationship() :
-	  #$self->_is_a_relationship();
-	  $self->_add_relationship( $parent, $current_term, $reltype, $ont);
-	}
+          my($relstring) = $line =~ /^\s*([<%~]|\@[^\@]+?\@)/;
 
-	$prev_spaces = $current_spaces;
-	$prev_term = $current_term;
+          my $reltype;
+
+          if ($relstring eq '<') {
+                $reltype = $self->_part_of_relationship;
+          } elsif ($relstring eq '%') {
+                $reltype = $self->_is_a_relationship;
+          } elsif ($relstring eq '~') {
+                $reltype = $self->_related_to_relationship;
+          } else {
+                $relstring =~ s/\@//g;
+                if ($self->_ont_engine->get_relationship_type($relstring)) {
+                  $reltype = $self->_ont_engine->get_relationship_type($relstring);
+                } else {
+                  $self->_ont_engine->add_relationship_type($relstring, $ont);
+                  $reltype = $self->_ont_engine->get_relationship_type($relstring);
+                }
+          }
+
+          #my $reltype = ($line =~ /^\s*</) ?
+          #$self->_part_of_relationship() :
+          #$self->_is_a_relationship();
+          $self->_add_relationship( $parent, $current_term, $reltype, $ont);
+        }
+
+        $prev_spaces = $current_spaces;
+        $prev_term = $current_term;
   }
   return $ont;
-}								# _parse_relationships_file
+}                                                                # _parse_relationships_file
 
 
 
@@ -668,7 +684,7 @@ sub _get_first_termid {
     else {
         $self->throw( "format error: no term id in line \"$line\"" );
     }
-    
+
 } # _get_first_termid
 
 
@@ -676,35 +692,35 @@ sub _get_first_termid {
 # Parses the name out of line.
 sub _get_name {
     my ( $self, $line, $termid ) = @_;
-    
+
     if ( $line =~ /([^;<%~]+);\s*$termid/ ) {
         my $name = $1;
-	# remove trailing and leading whitespace
+        # remove trailing and leading whitespace
         $name =~ s/\s+$//;
         $name =~ s/^\s+//;
         $name =~ s/\@.+?\@//;
-	# remove leading dollar character; also we default the name of the
-	# ontology to this name unless it is preset to something else
-	if(index($name,'$') == 0) {
-	    $name = substr($name,1);
-	    # replace underscores by spaces for setting the ontology name
-	    $self->ontology_name(join(" ",split(/_/,$name))) 
-		unless $self->ontology_name();
-	}
+        # remove leading dollar character; also we default the name of the
+        # ontology to this name unless it is preset to something else
+        if(index($name,'$') == 0) {
+            $name = substr($name,1);
+            # replace underscores by spaces for setting the ontology name
+            $self->ontology_name(join(" ",split(/_/,$name)))
+                unless $self->ontology_name();
+        }
         return $name;
     }
     else {
-        return undef;
+        return;
     }
-} # _get_name   
+} # _get_name
 
 
 # Parses the synonyms out of line.
 sub _get_synonyms {
     my ( $self, $line ) = @_;
-   
+
     my @synonyms = ();
-   
+
     while ( $line =~ /synonym\s*:\s*([^;<%~]+)/g ) {
         my $syn = $1;
         $syn =~ s/\s+$//;
@@ -712,7 +728,7 @@ sub _get_synonyms {
         push( @synonyms, $syn );
     }
     return @synonyms;
-    
+
 } # _get_synonyms
 
 
@@ -720,9 +736,9 @@ sub _get_synonyms {
 # Parses the db cross refs out of line.
 sub _get_db_cross_refs {
     my ( $self, $line ) = @_;
-   
+
     my @refs = ();
-   
+
     while ( $line =~ /;([^;<%~:]+:[^;<%~:]+)/g ) {
         my $ref = $1;
         if ( $ref =~ /synonym/ || $ref =~ /[A-Z]{1,8}:\d{3,}/ ) {
@@ -736,29 +752,29 @@ sub _get_db_cross_refs {
         push( @refs, $ref ) if defined $ref;
     }
     return @refs;
-    
-} 
+
+}
 
 
 # Parses the secondary go ids out of a line
 sub _get_secondary_termids {
     my ( $self, $line ) = @_;
     my @secs = ();
-   
+
 #    while ( $line =~ /,\s*([A-Z]{1,8}:\d{3,})/g ) {
     while ( $line =~ /,\s*(\w+:\w+)/g ) {
         my $sec = $1;
         push( @secs, $sec );
     }
     return @secs;
-    
-} # _get_secondary_termids 
+
+} # _get_secondary_termids
 
 
 # Counts the spaces at the beginning of a line in the relationships files
 sub _count_spaces {
     my ( $self, $line ) = @_;
-     
+
     if ( $line =~ /^(\s+)/ ) {
          return length( $1 );
     }
@@ -773,7 +789,7 @@ sub _next_term {
   my ( $self ) = @_;
 
   if ( ($self->_done() == TRUE) || (! $self->_defs_io())) {
-    return undef;
+    return;
   }
 
   my $line      = "";
@@ -785,7 +801,7 @@ sub _next_term {
   my $isobsolete;
 
   while( $line = ( $self->_defs_io->_readline() ) ) {
-    if ( $line !~ /\S/ 
+    if ( $line !~ /\S/
          ||   $line =~ /^\s*!/ ) {
       next;
     }
@@ -803,22 +819,19 @@ sub _next_term {
       $isobsolete = 1 if index($def,"OBSOLETE") == 0;
     }
     elsif ( $line =~ /^\s*definition_reference:\s*(.+)/ ) {
-      push( @def_refs, $self->unescape($1) );  
+      push( @def_refs, $self->unescape($1) );
     }
     elsif ( $line =~ /^\s*comment:\s*(.+)/ ) {
-      $comment = $self->unescape($1);  
+      $comment = $self->unescape($1);
     }
   }
   $self->_done( TRUE ) unless $line; # we'll come back until done
-
   return $self->_create_ont_entry( $next_term, $termid, $def,
                                    $comment, \@def_refs, $isobsolete);
 } # _next_term
 
 
 
-
-
 # Holds the GO engine to be parsed into
 sub _ont_engine {
     my ( $self, $value ) = @_;
@@ -826,13 +839,11 @@ sub _ont_engine {
     if ( defined $value ) {
         $self->{ "_ont_engine" } = $value;
     }
-    
+
     return $self->{ "_ont_engine" };
 } # _ont_engine
 
 
-
-
 # Used to create ontology terms.
 # Arguments: name, id
 sub _create_ont_entry {
@@ -841,13 +852,13 @@ sub _create_ont_entry {
     if((!defined($obsolete)) && (index(lc($name),"obsolete") == 0)) {
       $obsolete = 1;
     }
-
+    my $anno = $self->_to_annotation($dbxrefs);
     my $term = $self->term_factory->create_object(-name => $name,
-						  -identifier => $termid,
-						  -definition => $def,
-						  -comment => $cmt,
-						  -dblinks => $dbxrefs,
-						  -is_obsolete => $obsolete);
+                                                  -identifier => $termid,
+                                                  -definition => $def,
+                                                  -comment => $cmt,
+                                                  -dbxrefs => $anno,
+                                                  -is_obsolete => $obsolete);
 
     return $term;
 } # _create_ont_entry
@@ -861,7 +872,7 @@ sub _not_first_record {
     if ( defined $value ) {
         $self->{ "_not_first_record" } = $value;
     }
-    
+
     return $self->{ "_not_first_record" };
 } # _not_first_record
 
@@ -874,21 +885,32 @@ sub _done {
     if ( defined $value ) {
         $self->{ "_done" } = $value;
     }
-    
+
     return $self->{ "_done" };
 } # _done
 
 
-# Holds a term.  
+# Holds a term.
 sub _term {
     my ( $self, $value ) = @_;
 
     if ( defined $value ) {
         $self->{ "_term" } = $value;
     }
-    
+
     return $self->{ "_term" };
-} # _term  
-  
-  
+} # _term
+
+# convert simple strings to Bio::Annotation::DBLinks
+sub _to_annotation {
+    my ($self , $links) = @_;
+    return unless $links;
+    my @dbxrefs;
+    for my $string (@{$links}) {
+        my ($db, $id) = split(':',$string);
+        push @dbxrefs, Bio::Annotation::DBLink->new(-database => $db, -primary_id => $id);
+    }
+    return \@dbxrefs;
+}
+
 1;
