@@ -27,8 +27,7 @@ Steve Chervitz E<lt>sac@bioperl.orgE<gt>
 #'
 
 package Bio::Search::BlastUtils;
-use Bio::Root::Version;
-
+$Bio::Search::BlastUtils::VERSION = '1.7.7';
 
 =head2 tile_hsps
 
@@ -151,7 +150,7 @@ sub tile_hsps {
 #	printf "  Length = %d; Identical = %d; Conserved = %d; Conserved(1-10): %d",$hsp->length, $hsp->length(-TYPE=>'iden'), $hsp->length(-TYPE=>'cons'), $hsp->length(-TYPE=>'cons',-START=>0,-STOP=>10); 
 	($qstart, $qstop) = $hsp->range('query');
 	($sstart, $sstop) = $hsp->range('sbjct');
-	$frame = $hsp->frame;
+	$frame = $hsp->frame('hit');
 	$frame = -1 unless defined $frame;
 	($qstrand, $sstrand) = $hsp->strand;
 
@@ -486,9 +485,7 @@ sub collapse_nums {
            : be a standard, the structure of the HTML-formatted version
            : is even less so. Therefore, the use of this method to
            : reconstitute parsable Blast reports from HTML-format versions
-           : should be considered a temorary solution.
-
-See Also   : B<Bio::Search::Processor::BlastIO::new()>
+           : should be considered a temporary solution.
 
 =cut
 
