@@ -1,8 +1,9 @@
 #-----------------------------------------------------------------
-# $Id: IterationI.pm,v 1.4 2004/06/26 15:49:14 jason Exp $
 #
 # BioPerl module Bio::Search::Iteration::IterationI
 #
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+#
 # Cared for by Steve Chervitz <sac@bioperl.org>
 #
 # You may distribute this module under the same terms as perl itself
@@ -26,7 +27,7 @@ iteration from an iterated search result, such as PSI-BLAST.
     # First, open up a SearchIO stream
     use Bio::SearchIO;
     my $file = shift or die "Usage: $0 <BLAST-report-file>\n";
-    my $in = new Bio::SearchIO(-format => 'blast',
+    my $in = Bio::SearchIO->new(-format => 'blast',
                                -file => $file # comment out this line to read STDIN
                               );
     # Iterate over all results in the input stream
@@ -153,7 +154,7 @@ are still not below threshold in the current iteration.
 
 =item * oldhits()  [subset C]
 
-All hits that occured in a previous iteration, whether below or above
+All hits that occurred in a previous iteration, whether below or above
 threshold in the current iteration. Union of oldhits_below_threshold()
 + oldhits_newly_below_threshold() + oldhits_not_below_threshold()
 [subset H + subset I + subset G]. (Not applicable to the first
@@ -196,17 +197,27 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to one
 of the Bioperl mailing lists.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org              - General discussion
-  http://bio.perl.org/MailList.html  - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
- the bugs and their resolution.
- Bug reports can be submitted via email or the web:
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bio.perl.org
-  http://bugzilla.bioperl.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR 
 
@@ -224,7 +235,8 @@ This software is provided "as is" without warranty of any kind.
 
 =head1 APPENDIX
 
-The rest of the documentation details each of the object methods. Internal methods are usually preceded with a _
+The rest of the documentation details each of the object
+methods. Internal methods are usually preceded with a _
 
 =cut
 
@@ -233,13 +245,11 @@ The rest of the documentation details each of the object methods. Internal metho
 
 
 package Bio::Search::Iteration::IterationI;
-
+$Bio::Search::Iteration::IterationI::VERSION = '1.7.7';
 use strict;
-use vars qw(@ISA);
 
-use Bio::Root::RootI;
 
-@ISA = qw( Bio::Root::RootI );
+use base qw(Bio::Root::RootI);
 
 =head2 number
 
