@@ -1,4 +1,3 @@
-# $Id: megablast.pm 16123 2009-09-17 12:57:27Z cjfields $
 #
 # BioPerl module for Bio::SearchIO::megablast
 #
@@ -86,7 +85,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Jason Stajich
 
@@ -104,6 +103,7 @@ Internal methods are usually preceded with a _
 
 
 package Bio::SearchIO::megablast;
+$Bio::SearchIO::megablast::VERSION = '1.7.7';
 use strict;
 use vars qw(%MAPPING %MODEMAP $DEFAULT_BLAST_WRITER_CLASS);
 
@@ -138,7 +138,7 @@ BEGIN {
 	  );
 
 
-    $DEFAULT_BLAST_WRITER_CLASS = 'Bio::Search::Writer::HitTableWriter';
+    $DEFAULT_BLAST_WRITER_CLASS = 'Bio::SearchIO::Writer::HitTableWriter';
 }
 
 
@@ -274,7 +274,7 @@ sub next_result{
        $self->end_element({ 'Name' => 'MegaBlastOutput'});
        return $self->end_document();
    }
-   return 0;
+   return;
 }
 
 =head2 report_format
