@@ -1,11 +1,10 @@
-# $Id: featHandler.pm,v 1.10 2004/12/08 10:48:05 heikki Exp $
 # 
 #
 # Helper module for Bio::SeqIO::game::featHandler
 #
-# Cared for by Sheldon McKay <smckay@bcgsc.bc.ca>
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
 #
-# Copyright Sheldon McKay
+# Cared for by Sheldon McKay <mckays@cshl.edu>
 #
 # You may distribute this module under the same terms as perl itself
 #
@@ -37,21 +36,30 @@ to one of the Bioperl mailing lists.
 Your participation is much appreciated.
 
   bioperl-l@bioperl.org                  - General discussion
-  http://bioperl.org/MailList.shtml      - About the mailing lists
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
+
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution.
+of the bugs and their resolution. Bug reports can be submitted via the
+web:
 
-_Bug reports can be submitted via email or the web:
-
-  bioperl-bugs@bioperl.org
-  http://bugzilla.bioperl.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Sheldon McKay
 
-Email smckay@bcgsc.bc.ca
+Email mckays@cshl.edu
 
 =head1 APPENDIX
 
@@ -61,16 +69,15 @@ methods. Internal methods are usually preceded with a _
 =cut
 
 package Bio::SeqIO::game::featHandler;
-
-use Bio::SeqIO::game::gameSubs;
+$Bio::SeqIO::game::featHandler::VERSION = '1.7.7';
 use Bio::SeqFeature::Generic;
 use Bio::Location::Split;
 use Data::Dumper;
 use strict;
 
-use vars qw { @ISA };                                                                                
+use vars qw {};                                                                                
 
-@ISA = qw { Bio::SeqIO::game::gameSubs };
+use base qw(Bio::SeqIO::game::gameSubs);
 
 =head2 new
 
@@ -740,9 +747,11 @@ sub _add_CDS {
 	    #warn "chopping off right UTR\n";
 	    $exon->end( $stop );
 	}
-
-	$exon->start( $_->start ) unless $exon->start;
-	$exon->end( $_->end ) unless $exon->end;
+	
+	unless ($exon->valid_Location) {
+		$exon->start( $_->start );
+		$exon->end( $_->end );
+	}
 	$exon->strand ( $self->{curr_strand} );
 	push @exons_to_add, $exon;
     }
