@@ -1,4 +1,3 @@
-# $Id: NodeNHX.pm 16123 2009-09-17 12:57:27Z cjfields $
 #
 # BioPerl module for Bio::Tree::NodeNHX
 #
@@ -62,7 +61,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via
 the web:
 
-  http://bugzilla.open-bio.org/
+  https://github.com/bioperl/bioperl-live/issues
 
 =head1 AUTHOR - Aaron Mackey
 
@@ -86,6 +85,7 @@ Internal methods are usually preceded with a _
 # Let the code begin...
 
 package Bio::Tree::NodeNHX;
+$Bio::Tree::NodeNHX::VERSION = '1.7.7';
 use strict;
 
 
@@ -135,7 +135,7 @@ sub to_string{
    my ($self) = @_;
    my @tags = $self->get_all_tags;
    my $tagstr = '';
-   if( @tags ) {
+   if( scalar(@tags) > 0 ) {
        $tagstr = '[' . join(":", "&&NHX", 
 			    map { "$_=" .join(',',
 					      $self->get_tag_values($_))}
